package Task::BeLike::KWAKWA;

use strict;
use 5.008_005;

our $VERSION = '0.01';

# ABSTRACT: Be more like KWAKWA - use the modules he likes!

1;

__END__

=encoding utf-8

=head1 NAME

Task::BeLike::KWAKWA - Be more like KWAKWA!

=head1 TASK CONTENTS

=head2 Apps

=head3 L<App::Ack>

=head3 L<App::ForkProve>

=head2 Testing

=head3 L<Test::MockTime>

=head3 L<Test::Mojo> can be used to test Dancer2 apps too.

=head2 Web

=head3 L<Catalyst>

=head3 L<Dancer2>

=head3 L<Mojolicious>

=head1 AUTHOR

Paul Williams E<lt>kwakwa@cpan.orgE<gt>

=head1 COPYRIGHT

Copyright 2018- Paul Williams

=head1 LICENSE

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

=head1 SEE ALSO

L<Task::BeLike::DAGOLDEN>,
L<Task::BeLike::RJBS>.

=cut
